pub fn generate_persistence_mod_file(
entities: &[Entity],
config: &SchemaConfig,
) -> StringExpand description
Generate the top-level mod.rs for the persistence module.
Conditionally includes events and sync modules based on config.
pub fn generate_persistence_mod_file(
entities: &[Entity],
config: &SchemaConfig,
) -> StringGenerate the top-level mod.rs for the persistence module.
Conditionally includes events and sync modules based on config.